#
# spec file for package python-python-socks
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-python-socks%{psuffix}
Version:        2.5.3
Release:        1.3
Summary:        Core proxy client functionality for Python
License:        Apache-2.0
URL:            https://github.com/romis2012/python-socks
# gh#romis2012/python-socks#30
Source:         https://github.com/romis2012/python-socks/archive/refs/tags/v%{version}.tar.gz#/python-socks-%{version}.tar.gz
BuildRequires:  %{python_module anyio}
BuildRequires:  %{python_module async-timeout}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
# Source:         https://files.pythonhosted.org/packages/source/p/python-socks/python-socks-%%{version}.tar.gz
BuildRequires:  %{python_module wheel}
# SECTION test requirements
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module async_timeout}
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module flake8}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-trio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tiny-proxy}
BuildRequires:  %{python_module trio}
BuildRequires:  %{python_module trustme}
BuildRequires:  %{python_module yarl}
%endif
%python_subpackages

%description
The python-socks package provides a core proxy client functionality for Python.
Supports SOCKS4(a), SOCKS5, HTTP (tunneling) proxy and provides sync and async
(asyncio, trio, curio) APIs. You probably don't need to use python-socks
directly. It is used internally by aiohttp-socks and httpx-socks packages.

%prep
%autosetup -p1 -n python-socks-%{version}

%build
%if %{without test}
%pyproject_wheel
%endif

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
# try at least a simple import
%pytest
%endif

%if %{without test}
%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/python_socks
%{python_sitelib}/python_socks-%{version}.dist-info
%endif

%changelog
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 2.5.3:
  * Fix socks5 reply reading
* Tue Oct  1 2024 Dirk Müller <dmueller@suse.com>
- update to 2.5.2:
  * Use builtin async-timeout for Python>=3.11
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 2.5.1:
  * Fix socks5 reply reading
* Mon Apr 22 2024 Matej Cepl <mcepl@cepl.eu>
- Use tarball from GitHub (gh#romis2012/python-socks#30) to make
  running the test suite possible.
- Fix dependencies (bsc#1223181).
* Mon Jan  1 2024 Dirk Müller <dmueller@suse.com>
- update to 2.4.4:
  * Handle IndexError when loading socks5 reply
  * Fix connection logic (api v2)
  * Change empty reply error message (socks5)
  * ConnectReply.loads: fix IndexError in case no data
  * Redesign code base
  * Remove obsolete protocol implementation
  * Add Sans I/O based http proxy protocol implementation
  * Add Sans I/O socks4 implementation
  * Add simple Sans I/O based socks5 implementation
* Wed Jul  5 2023 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file.
* Tue Jul  4 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Feb 22 2023 ecsos <ecsos@opensuse.org>
- Update to 2.1.1
  - No changelog from upstream.
* Thu Oct  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 2.0.3:
  * Fix anyio exception handling
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  * Added anyio backend
  * Added new (v2) API for sync and trio backends
  * The code base has been completely redesigned
  * Fixed #14 anyio.BrokenResourceError
* Wed Apr 21 2021 Jiri Slaby <jslaby@suse.cz>
- initial package (1.2.4)
